@@ -88,6 +88,36 @@ def get_default_required(**kw):
         kw.setdefault('auth',True)
     return kw
     
+
+
+class ParameterPanel(object):
+    def __init__(self,**kw):
+        self.fields = kw
+        #~ object.__init__(self,**kw)
+        #~ for n in ('__getitem__','get','items','keys','values','__iter__','__len__'):
+            #~ setattr(self,n,getattr(kw,n))
+        
+    def values(self,*args,**kw): return self.fields.values(*args,**kw)
+    def keys(self,*args,**kw): return self.fields.keys(*args,**kw)
+    def __iter__(self,*args,**kw): return self.fields.__iter__(*args,**kw)
+    def __len__(self,*args,**kw): return self.fields.__len__(*args,**kw)
+    def __getitem__(self,*args,**kw): return self.fields.__getitem__(*args,**kw)
+    def get(self,*args,**kw):   return self.fields.get(*args,**kw)
+    def items(self,*args,**kw):   return self.fields.items(*args,**kw)
+        
+class ObservedPeriod(ParameterPanel):
+    def __init__(self,**kw):
+        kw.update(
+            start_date = models.DateField(_("Period from"),
+                blank=True,null=True,
+                help_text="""Start date of observed period"""),
+            end_date = models.DateField(_("until"),
+                blank=True,null=True,
+                help_text="""End date of observed period"""),
+            )
+        super(ObservedPeriod,self).__init__(**kw)
+
+
     
     
 class BoundAction(object):
@@ -388,12 +418,6 @@ class Actor(actions.Parametrizable):
     
     
     
-    #~ workflow_actions = None
-    #~ """
-    #~ A list of action names to be governed by workflows.
-    #~ """
-      
-    
     
     
     @classmethod
@@ -812,6 +836,7 @@ class Actor(actions.Parametrizable):
         if cls.workflow_state_field is not None:
             #~ for name,a in cls.get_state_actions():
             for a in cls.workflow_state_field.choicelist.workflow_actions:
+            #~ for a in cls.workflow_state_field.choicelist._actions_list: # 20130531 
                 #~ print 20120709, cls,name,a
                 #~ setattr(cls,name,fn())
                 setattr(cls,a.action_name,a) 
@@ -1161,7 +1186,7 @@ class Actor(actions.Parametrizable):
         whose default value is empty::
         
           class Clients(dd.Table):
-              parameters = dict(
+              parameters = dd.ParameterPanel(
                 ...
                 coached_since=models.DateField(blank=True))
                 
