@@ -17,11 +17,11 @@ which is available in :mod:`lino.dd`.
 
 Usage example::
 
-  @dd.receiver(dd.post_analyze)
+  @dd.receiver(dd.pre_analyze)
   def set_merge_actions(sender,**kw):
       modules = sender.modules
       for m in (modules.contacts.Person,modules.contacts.Company):
-          m.merge_row = dd.MergeAction(m)
+          m.define_action(merge_row=dd.MergeAction(m))
 
 If should not be used on models that have MTI children.
 
@@ -146,9 +146,7 @@ class MergePlan(object):
 
     
 class MergeAction(actions.RowAction):
-    """
-    Merge this object into another object of same class.
-    """
+    help_text = _("Merge this object into another object of same class.")
     label = _("Merge")
     sort_index = 31
     show_in_workflow = False
@@ -177,12 +175,14 @@ class MergeAction(actions.RowAction):
         
         keep_volatiles = []
         
+        #~ logger.info("20130421 MergeAction for %s : _lino_ddh.fklist is %s",model,model._lino_ddh.fklist)
         for m,fk in model._lino_ddh.fklist:
             if fk.name in m.allow_cascaded_delete:
                 fieldname = full_model_name(m,'_')
                 if not fieldname in keep_volatiles:
                     keep_volatiles.append(fieldname)
                     fields[fieldname] = models.BooleanField(m._meta.verbose_name_plural)
+            #~ logger.info("20130421 %r in %r",fk.name,m.allow_cascaded_delete)
             
         
         layout = dict()
@@ -204,7 +204,7 @@ class MergeAction(actions.RowAction):
                         tpl += ' '
                     tpl += name
             else:
-                tpl = ' '.join(weak_names)
+                tpl = ' '.join(keep_volatiles)
             main = """
             merge_to
             keep_volatiles
