@@ -47,9 +47,9 @@ except ImproperlyConfigured:
 
 
 import lino
-from lino.core.modeltools import app_labels
+from lino.core.dbutils import app_labels
 from lino.utils import rstgen
-from lino.core.modeltools import obj2str, full_model_name, sorted_models_list
+from lino.core.dbutils import obj2str, full_model_name, sorted_models_list
 
 
 def diffs(old,new,prefix=''):
@@ -98,7 +98,7 @@ class Command(BaseCommand):
             
         self.options = options
         
-        #~ settings.LINO.startup()
+        #~ settings.SITE.startup()
         
         state = dict()
         state.update(timestamp = datetime.datetime.now())
@@ -106,7 +106,7 @@ class Command(BaseCommand):
         
         
         
-        states_file = os.path.join(settings.LINO.project_dir,'states.pck')
+        states_file = os.path.join(settings.SITE.project_dir,'states.pck')
         
         if os.path.exists(states_file):
             fd = open(states_file)
