@@ -12,9 +12,16 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
-ur"""
-Lino has a hard-coded list of the five 
-basic "account types" or "top-level accounts".
+r"""
+This module is a Python implementation of the basic truths of accounting.
+
+It has a hard-coded list of "account types", 
+including the "top-level accounts".
+
+It has a hard-coded list of the Sheets
+
+Debit and Credit
+----------------
 
 An accounting transaction is either Debit or Credit.
 We represent this internally as a boolean, but define two names DEBIT and CREDIT:
@@ -25,7 +32,6 @@ True
 False
 
 
-
 Accounting Equation:
 
   Assets = Liabilities + Capital
@@ -48,23 +54,22 @@ Debit
 >>> print isinstance(AccountTypes.bank_accounts,Assets)
 True
 
-
   
 `Wikipedia <http://en.wikipedia.org/wiki/Debits_and_credits>`_ gives a 
-Summary table of standard increasing and decreasing attributes for the five 
-accounting elements:
+Summary table of standard increasing and decreasing attributes for the 
+five accounting elements:
 
-  ============= ===== ======
-  ACCOUNT TYPE	DEBIT	CREDIT
-  ============= ===== ======
-  Asset	        +	    −
-  Liability	    −	    +
-  Income	      −	    +
-  Expense	      +	    −
-  Equity	      −	    +      
-  ============= ===== ======
+============= ===== ======
+ACCOUNT TYPE  DEBIT CREDIT
+============= ===== ======
+Asset         \+    \−
+Liability     \−    \+
+Income        \−    \+
+Expense       \+    \−
+Equity        \−     \+      
+============= ===== ======
   
-The equivalent in Lino code is:
+The equivalent in Python is:
 
 >>> for t in AccountTypes.filter(top_level=True): #doctest: +NORMALIZE_WHITESPACE
 ...     print "%-12s|%-15s|%-6s" % (t.name, unicode(t), DC[t.dc])
@@ -75,6 +80,57 @@ expenses    |Expenses       |Debit
 capital     |Capital        |Credit
 
 
+The :class:`Sheet` class
+------------------------
+
+The class :class:`Sheet` represents the basic financial statements
+which every accounting package should implement.
+
+Lino currently defines three types of financial statements and defines 
+one class for each of them. 
+
+These classes are not meant to be instantiated, they are just 
+my suggestion for a standardized vocabulary.
+
+>>> print Sheet.objects
+(<class 'utils.Balance'>, <class 'utils.Earnings'>, <class 'utils.CashFlow'>)
+
+The `verbose_name` is what users see. It is a lazily translated 
+string, so we must call `unicode()` to see it:
+
+>>> for s in Sheet.objects:
+...     print unicode(s.verbose_name)
+Balance sheet
+Profit & Loss statement
+Cash flow statement
+
+French users will see:
+
+>>> from north.dbutils import set_language
+>>> set_language('fr')
+>>> for s in Sheet.objects:
+...     print unicode(s.verbose_name)
+Bilan
+Compte de résultats
+Tableau de financement
+
+
+The :meth:`Sheet.account_types` method.
+
+Assets, Liabilities and Capital are listed in the Balance Sheet.
+Income and Expenses are listed in the Profit & Loss statement.
+
+>>> print Balance.account_types()
+[<AccountTypes.assets:A>, <AccountTypes.liabilities:L>, <AccountTypes.capital:C>]
+
+>>> print Earnings.account_types()
+[<AccountTypes.incomes:I>, <AccountTypes.expenses:E>]
+
+>>> print CashFlow.account_types()
+[]
+
+
+
 TODO
 ----
 
@@ -108,9 +164,16 @@ TODO
   I found an excellent definition of these two terms at 
   `plancomptable.com <http://www.plancomptable.com/titre-II/titre-II.htm>`_:
 
-  - Un actif est un élément identifiable du patrimoine ayant une valeur économique positive pour l’entité, c’est-à-dire un élément générant une ressource que l’entité contrôle du fait d’événements passés et dont elle attend des avantages économiques futurs.
+  - Un actif est un élément identifiable du patrimoine ayant une 
+    valeur économique positive pour l’entité, c’est-à-dire un élément 
+    générant une ressource que l’entité contrôle du fait d’événements 
+    passés et dont elle attend des avantages économiques futurs.
   
-  - Un passif est un élément du patrimoine ayant une valeur économique négative pour l'entité, c'est-à-dire une obligation de l'entité à l'égard d'un tiers dont il est probable ou certain qu'elle provoquera une sortie des ressources au bénéfice de ce tiers, sans contrepartie au moins équivalente attendue de celui-ci. 
+  - Un passif est un élément du patrimoine ayant une valeur 
+    économique négative pour l'entité, c'est-à-dire une obligation de 
+    l'entité à l'égard d'un tiers dont il est probable ou certain 
+    qu'elle provoquera une sortie des ressources au bénéfice de ce 
+    tiers, sans contrepartie au moins équivalente attendue de celui-ci. 
   
 
 Some vocabulary
@@ -122,6 +185,8 @@ Some vocabulary
 
 """
 
+from __future__ import unicode_literals
+
 from django.utils.translation import ugettext_lazy as _
 #~ from lino.utils.choicelists import Choice,ChoiceList
 from lino import dd
@@ -135,8 +200,66 @@ DC = {
 }
 
 
+class Sheet(object):
+    """
+    Base class for a financial statement.
+    """
+    verbose_name = _("Financial statement") # Comptes annuels    Jahresabschluss               Jaarverslag              Aastaaruanne  
+    
+    @classmethod
+    def account_types(cls):
+        """
+        Return a list the top-level account types included in this Sheet
+        """
+        return [o for o in AccountTypes.objects() if o.sheet == cls and o.top_level]
+        
+class Balance(Sheet): 
+    """
+    In financial accounting, a 
+    balance sheet or 
+    statement of financial position 
+    is a summary of the financial balances of an organisation.
+
+    Assets, liabilities and ownership equity are listed as of a specific 
+    date, such as the end of its financial year. 
+    A balance sheet is often described as a "snapshot of a company's 
+    financial condition".
+    Of the four basic financial statements, the balance sheet is the only 
+    statement which applies to a single point in time of a business' calendar year.
+
+    A standard company balance sheet has three parts: assets, 
+    liabilities and ownership equity. The main categories of assets are 
+    usually listed first, and typically in order of liquidity. Assets 
+    are followed by the liabilities. The difference between the assets 
+    and the liabilities is known as equity or the net assets or the net 
+    worth or capital of the company and according to the accounting 
+    equation, net worth must equal assets minus liabilities.
+
+    https://en.wikipedia.org/wiki/Balance_sheet
+    
+    """
+    verbose_name = _("Balance sheet") #  Bilan              Bilanz                        Balans                   Bilanss       
+    
+
+#~ class ProfitOrLoss(Sheet):
+class Earnings(Sheet): 
+    """
+    https://en.wikipedia.org/wiki/Statement_of_comprehensive_income#Requirements_of_IFRS
+    """
+    verbose_name = _("Profit & Loss statement") #  Compte de résultat Gewinn- und Verlustrechnung   Winst-en-verliesrekening ...           
+
+class CashFlow(Sheet):
+    verbose_name = _("Cash flow statement") #  
+    
+    
+Sheet.objects = (Balance,Earnings,CashFlow)
+
+    
+
+
 class AccountType(dd.Choice):
     top_level = True
+    sheet = None
     #~ def __init__(self,value,text,name,dc=True,**kw):
         #~ self.dc = dc
         #~ super(AccountType,self).__init__(value,text,name)
@@ -150,30 +273,36 @@ class Assets(AccountType):
     text = _("Assets")   # Aktiva, Anleihe, Vermögen, Anlage
     name  = "assets"
     dc = DEBIT
+    sheet = Balance
 
 class Liabilities(AccountType):
     value = 'L'
     text = _("Liabilities") # Guthaben, Schulden, Verbindlichkeit  
     name  = "liabilities"
     dc = CREDIT
+    sheet = Balance
+
+class Capital(AccountType): # aka Owner's Equities
+    value = 'C' 
+    text = _("Capital") # Kapital 
+    name = "capital"
+    dc = CREDIT
+    sheet = Balance
 
 class Income(AccountType):
     value = 'I'
     text = _("Incomes") # Gain/Revenue     Einnahmen  Produits
     name  = "incomes" 
     dc = CREDIT
+    balance_sheet = True
+    sheet = Earnings
 
 class Expenses(AccountType):
     value = 'E' 
     text = _("Expenses") # Loss/Cost       Ausgaben   Charges
     name = "expenses"
     dc = DEBIT
-
-class Capital(AccountType):
-    value = 'C' 
-    text = _("Capital") # Kapital owner's Equities
-    name = "capital"
-    dc = CREDIT
+    sheet = Earnings
 
 class BankAccounts(Assets):
     top_level = False
@@ -200,15 +329,8 @@ add(Income())
 add(Expenses())
 add(Capital())
 add(BankAccounts())
-#~ add('A', _("Assets"),"asset",DEBIT)   # Aktiva, Anleihe, Vermögen, Anlage
-#~ add('L', _("Liabilities"),"liability",CREDIT) # Guthaben, Schulden, Verbindlichkeit
-#~ add('I', _("Incomes"),"income",CREDIT) # Gain/Revenue     Einnahmen  Produits
-#~ add('E', _("Expenses"),"expense",DEBIT) # Loss/Cost       Ausgaben   Charges
-#~ add('C', _("Capital"),"capital",CREDIT)  # Kapital owner's Equities
 
 
-#~ AccountTypes.add_item_instance(BankAccounts())
-
 
 def _test():
     import doctest
