@@ -31,9 +31,12 @@ import os
 import codecs
 #~ import logging
 #~ logger = logging.getLogger('lino')
+
+from django.conf import settings
+
 from lino.utils import dblogger as logger
 
-from north.babel import babel_values
+from north.dbutils import babel_values
 from lino.modlib.countries.models import Language
 
 
@@ -806,6 +809,7 @@ def objects():
             kw.update(iso2=iso2)
             yield Language(id=code,**kw)
         else:
-            logger.debug("%r : no name for default babel language %s",code,settings.SITE.DEFAULT_LANGUAGE)
+            logger.debug("%r : no name for default site language %s",
+                code,settings.SITE.DEFAULT_LANGUAGE.django_code)
     #~ logger.info("Installed %d languages",n)
           
\ No newline at end of file
