@@ -5,7 +5,7 @@ from __future__ import unicode_literals
 from lino import dd
 
 Product = dd.resolve_model('babel_tutorial.Product')
-from north.babel import babel_values
+from north.dbutils import babel_values
 
 def P(en,de,fr,cat):
     return Product(category=cat,**babel_values('name',en=en,de=de,fr=fr))
