@@ -53,6 +53,8 @@ class Site(lino.Site):
     """
     """
     
+    #~ 20130531 pending_threads = {}
+    
     console_user = None
     
     partners_app_label = 'contacts'
@@ -500,7 +502,7 @@ class Site(lino.Site):
     Set this to `False` if you don't need WebDAV-enabled links.
     """
     
-    max_auto_events = 36
+    max_auto_events = 72
     """
     Maximum number of automatic events to be generated 
     by :class:`lino.modlib.cal.models.EventOwner`.
@@ -913,8 +915,10 @@ class Site(lino.Site):
             meth = getattr(app_module,'get_todo_tables',None)
             if meth is not None:
                 #~ dblogger.debug("Running %s of %s", methname, mod.__name__)
-                for i in meth(ar):
-                    yield i
+                for table,text in meth(ar):
+                    if text is None:
+                        text = "%d " + unicode(table.label)
+                    yield (table,text)
 
     def get_installed_apps(self):
         """
@@ -1243,6 +1247,8 @@ class Site(lino.Site):
         
     def get_patterns(self):
         self.startup()
+        from lino.core.signals import database_ready
+        database_ready.send(self)
         #~ self.logger.info("20130418 get_patterns()")
         from django.conf.urls import patterns, url, include
 
@@ -1278,6 +1284,22 @@ class Site(lino.Site):
 
 
 
+    def get_event_summary(self,event,user):
+        from django.utils.translation import ugettext as _
+        s = event.summary
+        if event.user != user:
+            if event.access_class == self.modules.cal.AccessClasses.show_busy:
+                s = _("Busy")
+            s = event.user.username + ': ' + unicode(s)
+        elif self.project_model is not None and event.project is not None:
+            s += " " + unicode(_("with")) + " " + unicode(event.project)
+        if event.state:
+            s = ("(%s) " % unicode(event.state)) + s
+        n = event.guest_set.all().count()
+        if n:
+            s = ("[%d] " % n) + s
+        return s
+
 
 
 
