@@ -62,7 +62,7 @@ class BuildSiteCache(dd.RowAction):
     def run_from_ui(self,elem,ar):
         #~ rr.confirm(_("Are you sure?"))
         #~ rr.confirm(_("Are you really sure?"))
-        ar.ui.build_site_cache(True)
+        settings.SITE.ui.build_site_cache(True)
         return ar.success(
             """\
 Seems that it worked. Refresh your browser. 
@@ -107,13 +107,28 @@ class SiteConfig(dd.Model):
         #~ settings.SITE.on_site_config_saved(self)
         #~ settings.SITE.clear_site_config()
    
-
-def my_callback(sender,**kw):
+#~ def my_handler(sender=None,**kw):
+def my_handler(sender,**kw):
     settings.SITE.clear_site_config()
-dd.connection_created.connect(my_callback)
-models.signals.post_syncdb.connect(my_callback)
+    #~ kw.update(sender=sender)
+    dd.database_connected.send(sender)
+    #~ dd.database_connected.send(sender,**kw)
+    
 from djangosite.utils.djangotest import testcase_setup
-testcase_setup.connect(my_callback)
+testcase_setup.connect(my_handler)
+dd.connection_created.connect(my_handler)
+models.signals.post_syncdb.connect(my_handler)
+        
+   
+   
+#~ @dd.receiver(dd.database_connected)
+#~ def my_callback(sender,**kw):
+    #~ settings.SITE.clear_site_config()
+    
+#~ dd.connection_created.connect(my_callback)
+#~ models.signals.post_syncdb.connect(my_callback)
+#~ from djangosite.utils.djangotest import testcase_setup
+#~ testcase_setup.connect(my_callback)
 #~ dd.startup.connect(my_callback)
 #~ models.signals.post_save.connect(my_callback,sender=SiteConfig)
 #~ NOTE : I didn't manage to get that last line working. 
@@ -190,7 +205,7 @@ if settings.SITE.is_installed('contenttypes'):
                   if getattr(cl,'_meta',False) and not cl._meta.abstract:
                       #~ logger.info("20120205 adding(%r)",cl)
                       ct = contenttypes.ContentType.objects.get_for_model(cl)
-                      #~ chunks.append(ar.ui.ext_renderer.href_to(ct,unicode(cl._meta.verbose_name)))
+                      #~ chunks.append(settings.SITE.ui.ext_renderer.href_to(ct,unicode(cl._meta.verbose_name)))
                       chunks.append(ar.href_to(ct,unicode(cl._meta.verbose_name)))
           if obj is not None:
               #~ add(obj.model_class())
@@ -348,7 +363,7 @@ class Home(mixins.EmptyTable):
             chunks = []
             for mi in quicklinks.items:
                 chunks.append(' ')
-                chunks.append(ar.ui.ext_renderer.window_action_button(
+                chunks.append(settings.SITE.ui.ext_renderer.window_action_button(
                   ar,mi.bound_action))
             return xghtml.E.p('Quick Links:',*chunks)
       
