@@ -141,8 +141,6 @@ class ExtUI(base.UI):
             self.default_renderer = self.ext_renderer = ExtRenderer(self)
         else:
             self.default_renderer = self.plain_renderer
-            
-          
           
         names = set()
         for n in self.reserved_names:
@@ -159,7 +157,13 @@ class ExtUI(base.UI):
         
         post_ui_build.send(self)
         
-        #~ trigger creation of params_layout.params_store
+        #~ """
+        #~ setup_columns() methods may access the database
+        #~ """
+        #~ for res in actors.actors_list:
+            #~ res.setup_columns()
+
+        # trigger creation of params_layout.params_store
         for res in actors.actors_list:
             for ba in res.get_actions():
                 if ba.action.parameters:
@@ -296,7 +300,7 @@ class ExtUI(base.UI):
             tble.clear()
             tble.body.append(ar.no_data_text)
         
-        if False: # not ar.actor.hide_sums:
+        if not ar.actor.hide_sums:
             has_sum = False
             for i in sums:
                 if i:
