@@ -274,7 +274,8 @@ def delete_element(ar,elem):
     
     return HttpResponseDeleted()
     
-CATCHED_AJAX_EXCEPTIONS = (Warning,IntegrityError,exceptions.ValidationError)
+#CATCHED_AJAX_EXCEPTIONS = (Warning,IntegrityError,exceptions.ValidationError)
+CATCHED_AJAX_EXCEPTIONS = (Warning,exceptions.ValidationError)
 
 def ajax_error(e,rh,**kw):
     """
@@ -1046,7 +1047,7 @@ class GridConfig(View):
                 table=rpt,error=e)
             return settings.SITE.ui.error(None,msg,alert=True)
         #~ logger.info(msg)
-        settings.SITE.ui.build_site_cache(True)            
+        settings.SITE.ui.build_site_cache(True)
         return settings.SITE.ui.success(msg)
         
 MENUS = dict()        
